@@ -6,7 +6,6 @@ use Gearman::XS qw(:constants);
 
 has 'worker' => (
     builder => '_build_worker',
-    handles => [qw(add_servers)],
     is      => 'ro',
     isa     => 'Gearman::XS::Worker',
 );
@@ -33,4 +32,9 @@ sub work {
     }
 }
 
+sub add_servers {
+    my $self = shift;
+    return $self->worker->add_servers(@_);
+}
+
 1;
