@@ -52,15 +52,7 @@ has 'session' => (
 sub BUILD {
     my ($self) = @_;
 
-    foreach my $server ( split /,/, $self->server ) {
-        my ( $host, $port ) = split /:/, $server;
-
-        push @{ $self->{telnet} },
-          Net::Telnet::Gearman->new(
-            Host => $host || 'localhost',
-            Port => $port || 4730,
-          );
-    }
+    $self->_connect();
 
     $self->{session} = POE::Session->create(
         object_states => [
@@ -76,28 +68,54 @@ sub _start {
     $_[KERNEL]->delay( fetch_status => $_[OBJECT]->interval );
 }
 
+sub _connect {
+    my ($self) = @_;
+
+    $self->{telnet} = [];
+
+    foreach my $server ( split /,/, $self->server ) {
+        my ( $host, $port ) = split /:/, $server;
+
+        my $telnet = Net::Telnet::Gearman->new(
+            Host => $host || 'localhost',
+            Port => $port || 4730,
+        );
+
+        push @{ $self->{telnet} }, $telnet;
+    }
+}
+
 sub _fetch_status {
-    my %data = ();
+    my %data  = ();
+    my @error = ();
 
     foreach my $telnet ( $_[OBJECT]->telnet ) {
-        my $status = $telnet->status;
+        eval {
+            my $status = $telnet->status;
 
-        foreach my $row (@$status) {
-            $data{ $row->name } ||= {
-                name    => $row->name,
-                busy    => 0,
-                free    => 0,
-                queue   => 0,
-                running => 0,
-            };
-            $data{ $row->name }{busy}    += $row->busy;
-            $data{ $row->name }{free}    += $row->free;
-            $data{ $row->name }{queue}   += $row->queue;
-            $data{ $row->name }{running} += $row->running;
+            foreach my $row (@$status) {
+                $data{ $row->name } ||= {
+                    name    => $row->name,
+                    busy    => 0,
+                    free    => 0,
+                    queue   => 0,
+                    running => 0,
+                };
+                $data{ $row->name }{busy}    += $row->busy;
+                $data{ $row->name }{free}    += $row->free;
+                $data{ $row->name }{queue}   += $row->queue;
+                $data{ $row->name }{running} += $row->running;
+            }
+        };
+
+        # Try to re-open the telnet connection
+        if ($@) {
+            push @error, $@ if $@;
+            eval { $telnet->open };
         }
     }
 
-    $_[OBJECT]->callback->( [ values %data ] );
+    $_[OBJECT]->callback->( { data => [ values %data ], error => \@error } );
 
     $_[KERNEL]->delay( fetch_status => $_[OBJECT]->interval );
 }
@@ -130,6 +148,8 @@ See L<Gearman::Driver>.
 
 =item * L<Gearman::Driver::Job>
 
+=item * L<Gearman::Driver::Job::Method>
+
 =item * L<Gearman::Driver::Loader>
 
 =item * L<Gearman::Driver::Worker>
